--- **LootMaster** Helps you looting stuff acording your current class and spec when in party/raid. It will roll greed or disenchant in the items that you can't use, based on your current class/spec.

LootMaster = LibStub("AceAddon-3.0"):NewAddon("LootMaster", "AceEvent-3.0", "AceConsole-3.0");
--local LootMaster = _G.LootMaster;

local function getOption(info)
	return (info.arg and LootMaster.db.profile[info.arg] or LootMaster.db.profile[info[#info]]);
end;

local function setOption(info, value)
	local key = info.arg or info[#info];
	LootMaster.db.profile[key] = value;
end;

local options = {
	name = "LootMaster",
	handler = LootMaster,
	type = "group",
	args = {
		disenchant = {
			name = "Disenchant",
			desc = "Set to roll disenchant",
			type = "toggle",
			get = getOption,
			set = setOption,
		},
		test = {
			name = "Test",
			desc = "Testing",
			type = "execute",
			func = "Test",
		},
	},
}

local defaults = {
	profile = {
		disenchant = false,
	},
}

local usable_items = {};
local class;
local class_proficiencies = {};
--local class_stats = {};

-- Armor type
local cloth = GetSpellInfo(9078);
local leather = GetSpellInfo(9077);
local mail = GetSpellInfo(8737);
local plate = GetSpellInfo(750);
local shields = GetSpellInfo(9116);
local relic = GetSpellInfo(52665);
-- Weapon type
local axes_1H = GetSpellInfo(196);
local axes_2H = GetSpellInfo(197);
local bows = GetSpellInfo(264);
local xbows = GetSpellInfo(5011);
local daggers = GetSpellInfo(1180);
local guns = GetSpellInfo(266);
local fists = GetSpellInfo(15590);
local maces_1H = GetSpellInfo(198);
local maces_2H = GetSpellInfo(199);
local polearms = GetSpellInfo(200);
local staves = GetSpellInfo(227);
local swords_1H = GetSpellInfo(201);
local swords_2H = GetSpellInfo(202);
local thrown = GetSpellInfo(2567);
local wands = GetSpellInfo(5009);

function LootMaster:OnInitialize()
	LootMaster.db = LibStub("AceDB-3.0"):New("LootMasterDB", defaults, "Default");
	LibStub("AceConfig-3.0"):RegisterOptionsTable("LootMaster", options);
	LootMaster:RegisterChatCommand("lootmaster", "ChatCommand");
end;

function LootMaster:OnEnable()
	LootMaster:RegisterEvent("LOOT_BIND_CONFIRM");
	LootMaster:RegisterEvent("START_LOOT_ROLL");
	_, class = UnitClass("player");
	usable_items = LootMaster:GetProficiencies(class);
end;

function LootMaster:OnDisable()
	LootMaster:UnregisterEvent("LOOT_BIND_CONFIRM");
	LootMaster:UnregisterEvent("START_LOOT_ROLL");
end;

function LootMaster:ChatCommand(input)
	if not input or input:trim() == "" then
		LibStub("AceConfigCmd-3.0"):Open("LootMaster");
	else
		LibStub("AceConfigCmd-3.0").HandleCommand(LootMaster, "lootmaster", "LootMaster", input);
	end;
end;

function LootMaster:LOOT_BIND_CONFIRM(_, slotID)
	ConfirmLootSlot(slotID);
	--ConfirmBindOnUse();
	--for i = 1,GetNumLootItems(),1 do
		--ConfirmLootSlot(i);
	--end;
end;

function LootMaster:START_LOOT_ROLL(_, rollID, _)
	local _, name,_,_,_,_,_, canDisenchant = GetLootRollItemInfo(rollID);
	local itemName, itemLink, _, _, _, itemType, itemSubType, _, _, _, _ = GetItemInfo(name);
	local found = false;
	for i = 1,#usable_items,1 do
		if itemSubType == usable_items[i] then
			found = true;
		end;
	end;
	-- debug
	if itemType == "Gem" then found = true end;
	-- end-debug
	if not found then
		if canDisenchant and LootMaster.db.profile.disenchant then
			RollOnLoot(rollID,3);
		else
			RollOnLoot(rollID,2);
		end;
	end;

	-- if (itemType ~= "Armor" and itemType ~= "Weapon") then
		--Roll greed
		-- RollOnLoot(rollID,2);
	-- elseif (itemType == "Armor" and itemSubType ~= "Leather") then
		--Roll greed
		-- RollOnLoot(rollID,2);
	-- elseif (itemType == "Armor" and itemSubType == "Leather") then
		-- local stats = GetItemStats(itemLink);
		--Interface\FrameXML\GlobalStrings.lua
		--{ "ITEM_MOD_STAMINA_SHORT" = 10 }
	-- end;
end;

function LootMaster:GetProficiencies(class)
	if class == "DEATHKNIGHT" then
		class_proficiencies = { plate, relic, axes_1H, maces_1H, polearms, swords_1H, axes_2H, maces_2H, swords_2H };
	elseif class == "DRUID" then
		class_proficiencies = { leather, relic, daggers, fists, maces_1H, polearms, staves, maces_2H };
	elseif class == "HUNTER" then
		class_proficiencies = { leather, mail, axes_1H, daggers, fists, polearms, staves, swords_1H, axes_2H, swords_2H, bows, xbows, guns };
	elseif class == "MAGE" then
		class_proficiencies = { cloth, daggers, staves, swords_1H, wands };
	elseif class == "PALADIN" then
		class_proficiencies = { mail, plate, shields, relic, axes_1H, maces_1H, polearms, swords_1H, axes_2H, maces_2H, swords_2H };
	elseif class == "PRIEST" then
		class_proficiencies = { cloth, daggers, maces_1H, staves, wands };
	elseif class == "ROGUE" then
		class_proficiencies = { leather, axes_1H, daggers, fists, maces_1H, swords_1H, bows, xbows, guns, thrown };
	elseif class == "SHAMAN" then
		class_proficiencies = { leather, mail, shields, relic, axes_1H, daggers, fists, maces_1H, staves, axes_2H, maces_2H };
	elseif class == "WARLOCK" then
		class_proficiencies = { cloth, daggers, staves, swords_1H, wands };
	elseif class == "WARRIOR" then
		class_proficiencies = { mail, plate, axes_1H, daggers, fists, maces_1H, polearms, staves, swords_1H, axes_2H, maces_2H, swords_2H, bows, xbows, guns, thrown };
	end;
	return class_proficiencies;
end;

function LootMaster:Test()
	LootMaster:Print("#### TEST ####");
	for i = 1,#usable_items,1 do
		LootMaster:Print(usable_items[i]);
	end;
	LootMaster:Print("--------------");
end;
